function do_manif_sample()

tolerance = evalin('base', 'tolerance');
max_step = evalin('base', 'max_step');
arc_length = evalin('base', 'arc_length');
d = evalin('base', 'd');
a_min = evalin('base', 'a_min');
a_max = evalin('base', 'a_max');
Da_min = evalin('base', 'Da_min');
Da_max = evalin('base', 'Da_max');
D_min = evalin('base', 'D_min');
cB = evalin('base', 'cB');
eB = evalin('base', 'eB');



% modified Ikeda map
param = {1, 0.9, 1, 0.4, 6};
xF = find_periodic_md(@ikeda, 2, [-5 5; -5 5], [10 10], tolerance, diverge, max_step, false, param{:});
points = period_classify(@ikeda, xF, 2, 1e-6, param{:})
% points = 
%
%    [2x2 double]    [2]    'saddle'
%    [1x2 double]    [1]    'saddle'
%    [1x2 double]    [1]    'stable'


fixed = points{2, 1}(1, :);
cyc1 = points{1, 1}(1, :);
cyc2 = points{1, 1}(2, :);

[u_fix_f, arc] = sc_unstable(@ikeda, fixed, arc_length, d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[u_fix_b, arc] = sc_unstable(@ikeda, fixed, arc_length, -d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[s_fix_f, arc] = sc_stable(@ikeda, fixed, arc_length, 1, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[s_fix_b, arc] = sc_stable(@ikeda, fixed, arc_length, 1, -d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});

[u_cyc1_f, arc] = sc_unstable_cyc(@ikeda, cyc1, 2, arc_length, d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[u_cyc1_b, arc] = sc_unstable_cyc(@ikeda, cyc1, 2, arc_length, -d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[s_cyc1_f, arc] = sc_stable_cyc(@ikeda, cyc1, 2, arc_length, 1, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[s_cyc1_b, arc] = sc_stable_cyc(@ikeda, cyc1, 2, arc_length, 1, -d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});

[u_cyc2_f, arc] = sc_unstable_cyc(@ikeda, cyc2, 2, arc_length, d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[u_cyc2_b, arc] = sc_unstable_cyc(@ikeda, cyc2, 2, arc_length, -d, a_min, a_max, Da_min, Da_max, D_min, cB, diverge, param{:});
[s_cyc2_f, arc] = sc_stable_cyc(@ikeda, cyc2, 2, arc_length, 1, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[s_cyc2_b, arc] = sc_stable_cyc(@ikeda, cyc2, 2, arc_length, 1, -d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});

% construct cell arrays of computed manifolds
umanif = {u_fix_f, u_fix_b, u_cyc1_f, u_cyc1_b, u_cyc2_f, u_cyc2_b};
smanif = {s_fix_f, s_fix_b, s_cyc1_f, s_cyc1_b, s_cyc2_f, s_cyc2_b};

% plot points and manifolds
hfig = plot_manifolds(points, umanif, smanif);
hax = get(hfig, 'CurrentAxes');
set(hax, 'XLim', [-2 2], 'YLim', [-2.5 1.5]);


% shallow map
param = {4, 0.6, 0.153, 0.03};
xF = find_periodic_md(@shallow, 2, [0 6; 0 6], 40, 1e-8, 50, false, diverge, param{:});
points = period_classify(@shallow, xF, 2, 1e-6, diverge, param{:});
p0 = points{1, 1};
[uf, arc] = sc_unstable(@shallow, p0, 20, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[ub, arc] = sc_unstable(@shallow, p0, 20, -d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[sf, arc] = sc_stable(@shallow, p0, 20, 2, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});
[sb, arc] = sc_stable(@shallow, p0, 20, 2, -d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});

% construct cell arrays of computed manifolds
umanif = {uf, ub};
smanif = {sf, sb};

% plot points and manifolds
hfig = plot_manifolds(points, umanif, smanif);



[sc51, arc] = sc_stable_cyc(@ikeda, c51p1, 5, 10, d, a_min, a_max, Da_min, Da_max, D_min, eB, diverge, param{:});