function [param, points] = per_contin(fhandle, p, period, idx, ...
    low, up, step, tolerance, max_step, rnd, varargin)

%
% Following periodic points of the specified period,
% changing the parameter specified by its index
% (multi-dimensional)
% 
% fhandle   - function handle 
% p         - a point to follow
% period    - period of points to search
% idx       - parameter index
% low       - lower parameter value
% up        - upper parameter value
% step      - parameter step
% tolerance - checking point accuracy
% max_step  - maximal number of Newton steps exceeding this
%             value means that the Newton method do not
%             converge 
% rnd       - set initial conditions randomly or not
%             if true (or 1), then initial conditions are
%             chosen randomly (in the total amount of
%             init_num) if false (or 0), then the search
%             interval is divided into init_num equal
%             subdomains, and a middle point of each
%             subdomain is taken for the initial condition
% varargin  - cell array of the map parameters
%
% return values:
% param  - the vector of parameters
% points - the vector of periodic points found
%

nparam = nargin - 10;
if (idx > nparam)
    cprintf('err', 'ERROR: There is no parameter with the index %d.\n', idx);
    param = [];
    points = [];
    return;
end

prm = {};
for i = 1:(nargin-10)
    prm{i} = varargin{i};
end

param = low;
points = p;

prm{idx} = low + step;

if (step > 0)
    while (prm{idx} <= up)
        xF = find_periodic_md(@oligop, period, p, 0, 1e-8, 50, false, prm{:});
        p = xF;
        points = [points; xF];
        param = [param; prm{idx}];
        
        prm{idx} = prm{idx} + step;
    end
else
    while (prm{idx} >= up)
        prm{idx}
        xF = find_periodic_md(@oligop, period, p, 0, 1e-8, 50, false, prm{:});
        p = xF;
        points = [points; xF];
        param = [param; prm{idx}];
        
        prm{idx} = prm{idx} + step;
    end
end

    
