function y = shallow(x, q, b, c, rho)
%
% shallow map
% [Saeed Moghayer, Viennese Workshop 2012]
% [see also Brock and Starrett (1999); Dechert and Brock (2000); Maler et al. (2000)]
%
%     x -> psi(x) - psi'(x)/(y + 2*c*x)
% F: 
%     y -> (y + 2*c*x)/psi'(x)*exp(rho)
%                  
%  psi(x) = (1 - b)*x + x^q/(1 + x^q)
%

if (length(x) ~= 2)
    cprintf('err', 'ERROR: First argument must be a vector with 2 elements.\n');
    y = [];
    return;
else
    y(1) = (1-b)*x(1) + x(1)^q/(x(1)^q + 1) - (1 - b + (q*x(1)^(q-1))/(1 + x(1)^q)^2)/(x(2) + 2*c*x(1));
    y(2) = exp(rho)*(x(2) + 2*c*x(1))/(1 - b + (q*x(1)^(q-1))/(1 + x(1)^q)^2);
end;
