function [hfig, hcbar] = bd_plot(X, Y, C, maxperiod)

%
% Plot colour-coded period diagram
%
% X         - array of horizontal axes mesh
% Y         - array of vertical axes mesh
% C         - 2D array of period values
% maxperiod - maximal period to show colored (if values in C
%             are greater than maxperiod, then they are
%             coloured white)
%
% return values:
% hfig  - handle for the figure window
% hcbar - handle for the colour bar
%
% colour codes:
% divergence (-1) is coloured grey, while higher periods or
% chaos (0) are coloured white
%

idx = find(C > maxperiod);
C(idx) = 0;
hfig = figure;
pcolor(gca, X, Y, C);
set(gca, 'clim', [-1 maxperiod]);

% set colormap from file
load('bd_colors.mat');
colormap(contrastmap);

% set right color axis limits
caxis([-1.5 62.5]); 

% set colorbar show limits
hcbar = colorbar;
set(hcbar, 'ylim', [-1.5 maxperiod + 0.5]);
cticks = (-1:1:maxperiod);
set(hcbar, 'YTick', cticks);

% set smooth shading
shading flat;

