function stat = check_segment(p, p0, p1)

%
% Check if p lies inside the segment [p0, p1]
%
% return value:
% stat - exit status (0: inside, 1: forward of p1, -1:
% backward of p0)
%

lgth0 = norm(p - p0);
lgth1 = norm(p - p1);
ratio0 = lgth0/norm(p1 - p0);
ratio1 = lgth1/norm(p1 - p0);

if ((ratio0 < 1) && (ratio1 < 1))
    % inside [p0, p1]
    stat = 0;
    return;
end;

if ((ratio0 > 1) && (lgth1 < lgth0))
    % mapped outside [p0, p1], forward
    stat = 1;
    return;
elseif (ratio1 > 1)
    % mapped outside [p0, p1], backward
    stat = -1;
    return;
else
    % not mapped anywhere? p is Inf or NaN?
    cprintf('err', 'Something is wrong! This situation should not occur!\n');
    cprintf(get_colour('warn'), 'checked segement is [%.8f, %.8f], target point p = %.8f\n', p0, p1, p);
    stat = -2;
end;



