function J = jacob(fhandle, x, dx, varargin)

% 
% Calculate approximately the Jacobian matrix
%
% fhandle  - function (dynamical system) handle
% x        - the point in which Jacobian is calculated
% dx       - displacement estimate
% varargin - cell array of the function parameters
%
% return values:
% J - Jacobi matrix
%


k = length(x);
J = zeros(k, k);
xShifted = x;

for i = 1:k
    xShifted(i) = x(i) + dx;
    
    % partial derivatives with respect to i-th variable
    % i-th column of the matrix
    J(:, i) = (fhandle(xShifted, varargin{:}) - fhandle(x, varargin{:}))/dx;    
    xShifted(i) = x(i);
end